<?php
/*
Plugin Name: PostMarkApp Mail Replacement
Plugin URI: http://tmertz.com/projects/postmarkmailreplacement/
Description: A simple plugin that replaces the default wp_mail function with PostMarkApp (<a href="http://postmarkapp.com/">http://postmarkapp.com/</a>). This plugin is proudly sponsored by <a href="http://stupid-studio.com/">Stupid Studio</a>.
Version: 1.1
Author: Thomas Mertz
Author URI: http://tmertz.com/
*/

require_once("functions.php");

####################################################################
#
# UNINSTALLATION
#
####################################################################
function pm_wp_mail_uninstall() {
	delete_option( 'pm_wp_mail_key' );
	delete_option( 'pm_wp_mail_address' );
	delete_option( 'pm_wp_mail_type' );
	delete_option( 'pm_wp_mail_activate' );
}
register_deactivation_hook(__FILE__,'pm_wp_mail_uninstall');

####################################################################
#
# SWITCHING OUT WP_MAIL() FOR OUR CUSTOM MAIL
#
####################################################################
if( get_option( 'pm_wp_mail_activate' )==1 ) {
	if ( !function_exists('wp_mail') ) {
		function wp_mail($to, $subject, $body) {
			
			$message = postmark_json_encode($to, $subject, $body);
		
			$headers = array(
				'Accept: application/json',
				'Content-Type: application/json',
				'X-Postmark-Server-Token: ' . get_option( 'pm_wp_mail_key' ),
			);
		
			$ch = curl_init();
			curl_setopt($ch, CURLOPT_URL, 'https://api.postmarkapp.com/email');
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'POST');
			curl_setopt($ch, CURLOPT_POSTFIELDS, $message);
			curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
			curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, true);
			curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 2);
			curl_setopt($ch, CURLOPT_CAINFO, ABSPATH.'wp-content/plugins/postmarkmail/certificate/cacert.pem');
		
			$return = curl_exec($ch);
			$curlError = curl_error($ch);
			$httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
			
			return $return . '<br />' . $curlError . '<br />' . $httpCode;
		}
	}
}

####################################################################
#
# ADMINISTRATION OUTPUT
#
####################################################################
add_action('admin_menu', 'pm_wp_mail_plugin_menu');

function pm_wp_mail_plugin_menu() {
	add_menu_page('PostMarkApp', 'PostMarkApp', 'publish_posts', 'postmark-menu', 'pm_wp_mail_management','',150);
}

function pm_wp_mail_management() {
	if (!current_user_can('manage_options'))  {
		wp_die( __('Settings saved.') );
	}
	
	global $wpdb;
	
	if($_POST["pm-wp-mail-update-options"]=="yes") {
		
		update_option( 'pm_wp_mail_activate', $_POST["pm_wp_mail_activate"] );
		update_option( 'pm_wp_mail_key', $_POST["pm_wp_mail_key"] );
		update_option( 'pm_wp_mail_address', $_POST["pm_wp_mail_address"] );
		update_option( 'pm_wp_mail_type', $_POST["pm_wp_mail_type"] );
		
		echo "<div id=\"setting-error-settings_updated\" class=\"updated settings-error\"><p><strong>Your changes have been saved.</strong></p></div>";
	}

	echo "<div class=\"wrap\">\n";
	echo "<div id=\"icon-tools\" class=\"icon32\"></div><h2>PostMarkApp</h2>\n";
	echo "<form method=\"post\" action=\"" . $_SERVER["REQUEST_URI"] . "\">\n";
	echo "<table class=\"form-table\">\n";
	echo "<tbody>\n";
	
	echo "<tr valign=\"top\">\n";
	echo "<th scope=\"row\"><label for=\"pm_wp_mail_activate\">Activate</label></th>\n";
	echo "<td>\n";
	echo "<select name=\"pm_wp_mail_activate\" id=\"pm_wp_mail_activate\">\n";
	if(get_option( 'pm_wp_mail_activate' )==1) {
		echo "<option value=\"1\" selected=\"selected\">Yes</option>\n";
		echo "<option value=\"0\">No</option>\n";
	} else {
		echo "<option value=\"1\">Yes</option>\n";
		echo "<option value=\"0\" selected=\"selected\">No</option>\n";
	}
	echo "</select>\n";
	echo "</td>\n";
	echo "</tr>\n";
	
	echo "<tr valign=\"top\">\n";
	echo "<th scope=\"row\"><label for=\"pm_wp_mail_key\">API key</label></th>\n";
	echo "<td>\n";
	echo "<input type=\"text\" name=\"pm_wp_mail_key\" value=\"" . get_option( 'pm_wp_mail_key' ) . "\" size=\"60\" />\n";
	echo "</td>\n";
	echo "</tr>\n";
	
	echo "<tr valign=\"top\">\n";
	echo "<th scope=\"row\"><label for=\"pm_wp_mail_address\">PostMark email address</label></th>\n";
	echo "<td>\n";
	echo "<input type=\"text\" name=\"pm_wp_mail_address\" value=\"" . get_option( 'pm_wp_mail_address' ) . "\" size=\"60\" /><br /><span class=\"description\">Usually something like 'no-reply@yourdomain.com'.<br />Should match the sender signature you registered with PostMarkApp.</span>\n";
	echo "</td>\n";
	echo "</tr>\n";
	
	echo "<tr valign=\"top\">\n";
	echo "<th scope=\"row\"><label for=\"pm_wp_mail_type\">Email Type</label></th>\n";
	echo "<td>\n";
	echo "<select name=\"pm_wp_mail_type\" id=\"pm_wp_mail_type\">\n";
	if(get_option( 'pm_wp_mail_type' )==1) {
		echo "<option value=\"1\" selected=\"selected\">HTML</option>\n";
		echo "<option value=\"0\">Pure text</option>\n";
	} else {
		echo "<option value=\"1\">HTML</option>\n";
		echo "<option value=\"0\" selected=\"selected\">Pure text</option>\n";
	}
	echo "</select>\n";
	echo "</td>\n";
	echo "</tr>\n";
	
	echo "</tbody>\n";
	echo "</table>\n";
	echo "<p class=\"submit\"><input type=\"submit\" name=\"Submit\" class=\"button-primary\" value=\"Save Changes\"></p>\n";
	echo "<input type=\"hidden\" name=\"pm-wp-mail-update-options\" value=\"yes\" />\n";
	echo "</form>\n";
	echo "<hr style=\"border: 0; color: #ddd;background-color: #ddd;height: 1px;\" />";
	echo "<p style=\"text-align: right;\">This plugin is proudly sponsored by <a href=\"http://www.stupid-studio.com/\">Stupid Studio</a>.</p>";
	echo "<p style=\"text-align: right;\"><a href=\"http://www.stupid-studio.com/\"><img src=\"/wp-content/plugins/postmarkmail/stupid_logo.png\" style=\"border:0;\" alt=\"Stupid Studio\" /></a></p>";
	echo "</div>\n";
}
?>